@@ -1,4 +1,6 @@
 import csv
+import html
+import json
 import logging
 import os
 import re
@@ -13,6 +15,7 @@ from django.core.exceptions import ValidationError
 from django.utils.functional import lazy
 import xml.dom.minidom  # type: ignore
 
+from django.utils.safestring import mark_safe
 
 logger = logging.getLogger(__name__)
 
@@ -79,13 +82,20 @@ def format_timedelta(dt: timedelta, days_label: str = 'd', hours_label: str = 'h
         (1, seconds_label),
     )
     out = ""
-    seconds = int(dt.total_seconds())
+    seconds_f = dt.total_seconds()
+    seconds = int(seconds_f)
     for n_secs, label in parts:
         n, remainder = divmod(seconds, n_secs)
         if n > 0 and label:
             out += str(n) + label
             seconds = remainder
-    return out.strip()
+    out_str = out.strip()
+    if not out_str:
+        if seconds_f >= 0.001:
+            out_str = '{:0.3f}'.format(int(seconds_f * 1000.0) * 0.001) + seconds_label
+        else:
+            out_str = '0' + seconds_label
+    return out_str.strip()
 
 
 def format_xml(content: str, encoding: str = 'UTF-8', exceptions: bool = False) -> str:
@@ -166,6 +176,15 @@ def format_xml_file(full_path: str, encoding: str = 'UTF-8', exceptions: bool =
     return b''
 
 
+def format_as_html_json(value: Any) -> str:
+    """
+    Returns value as JSON-formatted value in HTML.
+    :param value: Any value which can be converted to JSON by json.dumps
+    :return: str
+    """
+    return mark_safe(html.escape(json.dumps(value, indent=4)).replace('\n', '<br/>').replace(' ', '&nbsp;'))
+
+
 def format_csv(rows: List[List[Any]], dialect: str = 'excel') -> str:
     """
     Formats rows to CSV string content.
